@@ -239,7 +239,8 @@ class FuzzyPrompt(BaseComplexPrompt):
     :param pointer: Pointer symbol.
     :param style: Style dict to apply.
     :param vi_mode: Use vi kb for the prompt.
-    :param qmark: Question mark symbol.
+    :param qmark: The custom symbol to display infront of the question before its answered.
+    :param amark: The custom symbol to display infront of the question after its answered.
     :param transformer: Transform the result to output, this is only visual effect.
     :param filter: A callable to filter the result, updating the user input before returning the result.
     :param instruction: Instruction to display after the message.
@@ -254,6 +255,8 @@ class FuzzyPrompt(BaseComplexPrompt):
     :param validate: A callable or Validator instance to validate user selection.
     :param invalid_message: Message to display when input is invalid.
     :param keybindings: Custom keybindings to apply.
+    :param cycle: Return to top item if hit bottom or vice versa.
+    :param wrap_lines: Soft wrap question lines when question exceeds the terminal width.
     """
 
     def __init__(
@@ -265,6 +268,7 @@ class FuzzyPrompt(BaseComplexPrompt):
         style: InquirerPyStyle = None,
         vi_mode: bool = False,
         qmark: str = "?",
+        amark: str = "?",
         transformer: Callable[[Any], Any] = None,
         filter: Callable[[Any], Any] = None,
         instruction: str = "",
@@ -279,6 +283,8 @@ class FuzzyPrompt(BaseComplexPrompt):
         validate: Union[Callable[[Any], bool], Validator] = None,
         invalid_message: str = "Invalid input",
         keybindings: Dict[str, List[Dict[str, Any]]] = None,
+        cycle: bool = True,
+        wrap_lines: bool = True,
         session_result: SessionResult = None,
     ) -> None:
         if not keybindings:
@@ -300,6 +306,7 @@ class FuzzyPrompt(BaseComplexPrompt):
             style=style,
             vi_mode=vi_mode,
             qmark=qmark,
+            amark=amark,
             transformer=transformer,
             filter=filter,
             validate=validate,
@@ -307,11 +314,13 @@ class FuzzyPrompt(BaseComplexPrompt):
             multiselect=multiselect,
             instruction=instruction,
             keybindings=keybindings,
+            cycle=cycle,
+            wrap_lines=wrap_lines,
             session_result=session_result,
         )
         self._default = default if not isinstance(default, Callable) else default(self._result)  # type: ignore
         self._dimmension_height, self._dimmension_max_height = calculate_height(
-            height, max_height, offset=3 if not self._border else 5
+            height, max_height, offset=3, wrap_lines_offset=self.wrap_lines_offset
         )
 
         self._content_control = InquirerPyFuzzyControl(
@@ -329,8 +338,9 @@ class FuzzyPrompt(BaseComplexPrompt):
 
         self._buffer = Buffer(on_text_changed=self._on_text_changed)
         message_window = Window(
-            height=LayoutDimension.exact(1),
+            height=LayoutDimension.exact(1) if not self._wrap_lines else None,
             content=FormattedTextControl(self._get_prompt_message, show_cursor=False),
+            wrap_lines=self._wrap_lines,
         )
         input_window = Window(
             height=LayoutDimension.exact(1),
@@ -510,18 +520,6 @@ class FuzzyPrompt(BaseComplexPrompt):
         )
         self._task.add_done_callback(self._filter_callback)
 
-    def _handle_down(self) -> None:
-        """Move down."""
-        self.content_control.selected_choice_index = (
-            self.content_control.selected_choice_index + 1
-        ) % self.content_control.choice_count
-
-    def _handle_up(self) -> None:
-        """Move up."""
-        self.content_control.selected_choice_index = (
-            self.content_control.selected_choice_index - 1
-        ) % self.content_control.choice_count
-
     def _toggle_choice(self) -> None:
         """Handle tab event, alter the `selected` state of the choice."""
         current_selected_index = self.content_control.selection["index"]
