@@ -1,5 +1,4 @@
 """Module contains the class to create an input prompt."""
-import os
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from prompt_toolkit.completion import NestedCompleter
@@ -11,7 +10,7 @@ from prompt_toolkit.shortcuts.prompt import CompleteStyle, PromptSession
 from prompt_toolkit.validation import ValidationError, Validator
 
 from InquirerPy.base import BaseSimplePrompt
-from InquirerPy.enum import INQUIRERPY_KEYBOARD_INTERRUPT, INQUIRERPY_POINTER_SEQUENCE
+from InquirerPy.enum import INQUIRERPY_POINTER_SEQUENCE
 from InquirerPy.exceptions import InvalidArgument
 from InquirerPy.utils import InquirerPyStyle, SessionResult
 
@@ -23,30 +22,21 @@ class InputPrompt(BaseSimplePrompt):
 
     This class is used for input prompt.
 
-    :param message: the question to ask
-    :type message: Union[str, Callable[[SessionResult], str]]
-    :param style: a dictionary of style to apply
-    :type style: InquirerPyStyle
-    :param vi_mode: use vi kb for the prompt
-    :type vi_mode: bool
-    :param default: the default result
-    :type default: Union[str, Callable[[SessionResult], str]]
-    :param qmark: question qmark to display
-    :type qmark: str
-    :param completer: add auto completer to user input
-    :type completer: Union[Dict[str, str], Completer]
-    :param multicolumn_complete: complete in multi column
-    :type multicolumn_complete: bool
-    :param multiline: enable multiline mode
-    :type multiline: bool
-    :param validate: a callable or a validation class to validate user input
-    :type validate: Union[Callable[[str], bool], Validator]
-    :param invalid_message: the error message to display when input is invalid
-    :type invalid_message: str
-    :param transformer: a callable to transform the result, this is visual effect only
-    :type transformer: Callable[[str], Any]
-    :param filter: a callable to filter the result, updating the user input before returning the result
-    :type filter: Callable[[str], Any]
+    :param message: The question to ask.
+    :param style: A dictionary of style to apply.
+    :param vi_mode: Use vi kb for the prompt.
+    :param default: The default result.
+    :param qmark: The custom symbol to display infront of the question before its answered.
+    :param amark: The custom symbol to display infront of the question after its answered.
+    :param instruction: Instruction to display after the question message.
+    :param completer: Add auto completer to user input.
+    :param multicolumn_complete: Complete in multi column.
+    :param multiline: Enable multiline mode.
+    :param validate: A callable or a validation class to validate user input.
+    :param invalid_message: The error message to display when input is invalid.
+    :param transformer: A callable to transform the result, this is visual effect only.
+    :param filter: A callable to filter the result, updating the user input before returning the result.
+    :param wrap_lines: Soft wrap question lines when question exceeds the terminal width.
     """
 
     def __init__(
@@ -56,6 +46,8 @@ class InputPrompt(BaseSimplePrompt):
         vi_mode: bool = False,
         default: Union[str, Callable[[SessionResult], str]] = "",
         qmark: str = "?",
+        amark: str = "?",
+        instruction: str = "",
         completer: Union[Dict[str, Optional[str]], Completer] = None,
         multicolumn_complete: bool = False,
         multiline: bool = False,
@@ -63,21 +55,24 @@ class InputPrompt(BaseSimplePrompt):
         invalid_message: str = "Invalid input",
         transformer: Callable[[str], Any] = None,
         filter: Callable[[str], Any] = None,
+        wrap_lines: bool = True,
         session_result: SessionResult = None,
         **kwargs,
     ) -> None:
-        """Construct a PromptSession based on parameters and apply key_bindings."""
         super().__init__(
             message,
             style,
             vi_mode=vi_mode,
             qmark=qmark,
+            amark=amark,
+            instruction=instruction,
             validate=validate,
             invalid_message=invalid_message,
             transformer=transformer,
             filter=filter,
             session_result=session_result,
             default=default,
+            wrap_lines=wrap_lines,
         )
         if not isinstance(self._default, str):
             raise InvalidArgument(
@@ -114,7 +109,7 @@ class InputPrompt(BaseSimplePrompt):
         @self._kb.add(Keys.Enter, filter=~is_multiline)
         def enter(event):
             try:
-                self._session.validator.validate(self._session.default_buffer)
+                self._session.validator.validate(self._session.default_buffer)  # type: ignore
             except ValidationError:
                 self._session.default_buffer.validate_and_handle()
             else:
@@ -126,7 +121,7 @@ class InputPrompt(BaseSimplePrompt):
         @self._kb.add(Keys.Escape, Keys.Enter, filter=is_multiline)
         def multiline_enter(event):
             try:
-                self._session.validator.validate(self._session.default_buffer)
+                self._session.validator.validate(self._session.default_buffer)  # type: ignore
             except ValidationError:
                 self._session.default_buffer.validate_and_handle()
             else:
@@ -149,6 +144,7 @@ class InputPrompt(BaseSimplePrompt):
             is_password=kwargs.pop("is_password", False),
             multiline=self._multiline,
             complete_style=self._complete_style,
+            wrap_lines=wrap_lines,
         )
 
     def _get_prompt_message(
@@ -160,18 +156,18 @@ class InputPrompt(BaseSimplePrompt):
 
         Change the user input path to the 'answer' color in style.
 
-        :param pre_answer: the formatted text to display before answering the question
-        :type pre_answer: Optional[Tuple[str, str]]
-        :param post_answer: the formatted text to display after answering the question
-        :type post_answer: Optional[Tuple[str, str]]
-        :return: the formatted text for PromptSession
-        :rtype: List[Tuple[str, str]]
+        :param pre_answer: The formatted text to display before answering the question.
+        :param post_answer: The formatted text to display after answering the question.
+        :return: The formatted text for PromptSession.
         """
         if not pre_answer:
-            if self._multiline:
+            if self._multiline and not self._instruction:
                 pre_answer = ("class:instruction", " ESC + Enter to finish input")
             else:
-                pre_answer = ("class:instruction", " ")
+                pre_answer = (
+                    "class:instruction",
+                    " %s " % self.instruction if self.instruction else " ",
+                )
         if not post_answer:
             if self._multiline and self.status["result"]:
                 lines = self.status["result"].split("\n")
@@ -192,22 +188,5 @@ class InputPrompt(BaseSimplePrompt):
             )
         return formatted_message
 
-    def execute(self, raise_keyboard_interrupt: bool = True) -> Optional[str]:
-        """Display the prompt and return the result.
-
-        :param raise_keyboard_interrupt: raise kbi exception when user hit 'c-c'
-        :type raise_keyboard_interrupt: bool
-        :return: user entered value
-        :rtype: str
-        """
-        result = self._session.prompt(default=self._default)
-        if result == INQUIRERPY_KEYBOARD_INTERRUPT:
-            if raise_keyboard_interrupt and not os.getenv(
-                "INQUIRERPY_NO_RAISE_KBI", False
-            ):
-                raise KeyboardInterrupt
-            else:
-                result = None
-        if not self._filter:
-            return result
-        return self._filter(result)
+    def _run(self) -> str:
+        return self._session.prompt(default=self._default)
